#
# spec file for package libabw
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libabw-0_1-1
Name:           libabw
Version:        0.1.3
Release:        1.22
Summary:        Library for parsing the Abiword file format structure
License:        MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://wiki.documentfoundation.org/DLP/Libraries/libabw
Source0:        http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-generators-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
Libabw is library providing ability to interpret and import AbiWord documents
into various applications.

%package -n %{libname}
Summary:        Library for parsing the AbiWord file format structure
Group:          System/Libraries

%description -n %{libname}
Libabw is library providing ability to interpret and import AbiWord documents
into various applications.

%package devel
Summary:        Files for Developing with libabw
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Libabw is library providing ability to interpret and import AbiWord documents
into various applications.

This package contains the libabw development files.

%package devel-doc
Summary:        Documentation for the libabw API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libabw API.

%package tools
Summary:        Tools to work with documents in AbiWord file-format
Group:          Productivity/Publishing/Word

%description tools
This package contains tools to work with documents in AbiWord file-format.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-silent-rules \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}-devel/html
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

cp -p COPYING.* ChangeLog %{buildroot}%{_docdir}/%{name}-devel/

%fdupes -s %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING.*
%doc ChangeLog
%{_libdir}/*.so.*

%files devel
%doc %dir %{_docdir}/%{name}-devel/
%doc %{_docdir}/%{name}-devel/[A-Z]*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libabw*.pc
%{_includedir}/libabw-*

%files devel-doc
%doc %{_docdir}/%{name}-devel/html/

%files tools
%license COPYING.*
%doc ChangeLog
%{_bindir}/*

%changelog
* Sun Aug 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1.3:
  - Fix a memory access error found by oss-fuzz.
  - Configure with --disable-werror by default.
  - Disable expanding entities by XML parser as a vulnerability
    prevention measure. Abiword-saved documents do not contain entities,
    so there is no difference in behavior.
* Mon Jan  1 2018 tchvatal@suse.com
- Version update to 0.1.2:
  * Fix several issues identified by Coverity.
  * Parse paragraph and cell borders.
  * Improve parsing of lists.
  * Fix build with boost >= 1.59.
  * Make the output of abw2* --help more compatible with help2man.
  * Fix various problems when parsing broken files found by oss-fuzz.
  * Require C++11 for build.
  * Parse fields. (tdf#74466)
  * Parse floating (not inline) images. (tdf#74463)
  * Parse text boxes.
  * Drop outdated MSVC project files.
  * Set minimal width/height of inline images (which usually do not have
    dimensions set in the file) to 1 inch. (tdf#74462)
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Mar 24 2016 tchvatal@suse.com
- Add copying also to the library shipped
* Wed Nov 11 2015 idonmez@suse.com
- Fix compilation with boost 1.59
* Tue Jan 13 2015 tchvatal@suse.com
- Change the url to new one
* Mon Dec 22 2014 tchvatal@suse.com
- Version bump to 0.1.1:
  * Various small fixes
* Wed Aug 13 2014 fcrozat@suse.com
- Fix source url.
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI change
  * Remove dependency on libwpd-devel
  * Add dependency on librevenge-devel
* Tue May 20 2014 tchvatal@suse.com
- Fix build on SLE11.
* Wed Apr 30 2014 crrodriguez@opensuse.org
- This package also needs -fvisibility-inlines-hidden to
  cut down the bloat of the exported symbol table in around 200
  symbols less.
* Mon Mar 10 2014 fstrba@suse.com
- Fix descriptions in spec file
  * libabw handles AbiWord files
- Fix license
  * libabw is released under MPL-2.0
* Tue Feb 25 2014 tchvatal@suse.com
- Version bump to 0.0.2:
  * various bugfixes
  * build fixes with various boost versions.
* Fri Jan 17 2014 tchvatal@suse.com
- Initial commit, package will be required with libreoffice 4.2
